@@ -358,7 +358,7 @@ Mojo::Command - Command Base Class
     my $self = shift;
 
     # Handle options
-    local @ARGV = @_ if @_;
+    local @ARGV = @_;
     GetOptions('something' => sub { $something = 1 });
 
     # Magic here! :)
