@@ -1,7 +1,5 @@
 package ojo;
-
-use strict;
-use warnings;
+use Mojo::Base -strict;
 
 # "I heard beer makes you stupid.
 #  No I'm... doesn't."
@@ -69,7 +67,7 @@ sub _request {
   my ($message, $code) = $tx->error;
   warn qq/Problem loading URL "$_[0]". ($message)\n/ if $message && !$code;
 
-  $tx->res;
+  return $tx->res;
 }
 
 1;
